@@ -108,12 +108,14 @@ void set_keepalive_options(int fd)
 		return;
 	}
 
+# if defined(TCP_KEEPIDLE)
 	optval = 600;
 	ret = setsockopt(fd, SOL_TCP, TCP_KEEPIDLE, &optval, optlen);
 	if (ret) {
 		xdebug_log_ex(XLOG_CHAN_DEBUG, XLOG_WARN, "KEEPALIVE", "Could not set TCP_KEEPIDLE to %d: %s.", optval, strerror(errno));
 		return;
 	}
+# endif
 
 # if defined(TCP_KEEPCNT)
 	optval = 20;
@@ -551,7 +553,7 @@ void xdebug_debug_init_if_requested_on_xdebug_break()
 		return;
 	}
 
-	if (xdebug_lib_start_if_mode_is_trigger()) {
+	if (xdebug_lib_start_if_mode_is_trigger(XDEBUG_MODE_STEP_DEBUG)) {
 		xdebug_init_debugger();
 	}
 }
@@ -568,6 +570,7 @@ static int xdebug_handle_start_session()
 {
 	int   activate_session = 0;
 	zval *dummy;
+	char *dummy_env;
 
 	/* Set session cookie if requested */
 	if (
@@ -584,6 +587,16 @@ static int xdebug_handle_start_session()
 		xdebug_update_ide_key(Z_STRVAL_P(dummy));
 
 		xdebug_setcookie("XDEBUG_SESSION", sizeof("XDEBUG_SESSION") - 1, Z_STRVAL_P(dummy), Z_STRLEN_P(dummy), time(NULL) + XDEBUG_COOKIE_EXPIRE_TIME, "/", 1, NULL, 0, 0, 1, 0);
+		activate_session = 1;
+	} else if (
+		(dummy_env = getenv("XDEBUG_SESSION_START")) != NULL
+	) {
+		xdebug_update_ide_key(dummy_env);
+
+		if (!SG(headers_sent)) {
+			xdebug_setcookie("XDEBUG_SESSION", sizeof("XDEBUG_SESSION") - 1, XG_DBG(ide_key), strlen(XG_DBG(ide_key)), time(NULL) + XDEBUG_COOKIE_EXPIRE_TIME, "/", 1, NULL, 0, 0, 1, 0);
+		}
+
 		activate_session = 1;
 	} else if (
 		(dummy = zend_hash_str_find(Z_ARR(PG(http_globals)[TRACK_VARS_COOKIE]), "XDEBUG_SESSION", sizeof("XDEBUG_SESSION") - 1)) != NULL
@@ -630,9 +643,9 @@ void xdebug_debug_init_if_requested_at_startup(void)
 	}
 
 	if (
-		xdebug_lib_start_with_request() ||
+		xdebug_lib_start_with_request(XDEBUG_MODE_STEP_DEBUG) ||
 		(!xdebug_lib_never_start_with_request() && xdebug_handle_start_session()) ||
-		xdebug_lib_start_with_trigger(&found_trigger_value)
+		xdebug_lib_start_with_trigger(XDEBUG_MODE_STEP_DEBUG, &found_trigger_value)
 	) {
 		if (found_trigger_value) {
 			xdebug_update_ide_key(found_trigger_value);
